@@ -20,6 +20,7 @@ LOGGER = logging.getLogger("cfnlint")
 samtranslator_logger = logging.getLogger("samtranslator")
 samtranslator_logger.setLevel(logging.CRITICAL)
 
+
 # Override SAM validation as cfn-lint does thoese
 # checks already
 # pylint: disable=unused-argument
@@ -84,12 +85,10 @@ class Transform:
                             self._parameters[v] = "Alias"
 
         for _, resource in all_resources.items():
-
             resource_type = resource.get("Type")
             resource_dict = resource.get("Properties")
 
             if resource_type == "AWS::Serverless::Function":
-
                 if resource_dict.get("PackageType") == "Image":
                     Transform._update_to_s3_uri("ImageUri", resource_dict)
                 else:
@@ -114,6 +113,7 @@ class Transform:
                     "DefinitionBody" not in resource_dict
                     and "Auth" not in resource_dict
                     and "Cors" not in resource_dict
+                    and "DisableExecuteApiEndpoint" not in resource_dict
                 ):
                     Transform._update_to_s3_uri("DefinitionUri", resource_dict)
                 else:
@@ -218,7 +218,7 @@ class Transform:
         if isinstance(uri_property, dict):
             if len(uri_property) == 1:
                 for k in uri_property.keys():
-                    if k == "Ref":
+                    if k in ["Ref", "Fn::Sub"]:
                         resource_property_dict[property_key] = s3_uri_value
             return
         if Transform.is_s3_uri(uri_property):
